@@ -18,6 +18,8 @@ class Util:
         return local_filename
 
     def evaluate_sql(path_to_db, query, display_table=True):
+        if not os.path.exists(path_to_db):
+            raise FileNotFoundError()
         conn = sqlite3.connect(path_to_db)
         cursor = conn.execute(query)
         attributes = [description[0] for description in cursor.description]
@@ -57,8 +59,9 @@ class Util:
                     if 0.8 <= check:
                         score += partial_score_exact
                     print("    > ", check, ", score: ", round(score, 4))
-        except:
+        except Exception as e:
             print('exception caught, aborting')
+            print(e)
             pass  # catch, return
         else:
             # if the solution isn't exact, apply other rules
